@@ -177,7 +177,12 @@ def next(ctx, version):
 @cli.command()
 @click.pass_context
 @click.argument("version", type=str)
-def get(ctx, version):
+@click.option(
+    "--no-link",
+    is_flag=True,
+    help="This option suppresses a link, even if available.",
+)
+def get(ctx, version, no_link):
     """Returns a given version from the Changelog."""
     kacl_changelog = load_changelog(ctx)
 
@@ -185,6 +190,8 @@ def get(ctx, version):
     kacl_version = kacl_changelog.get(version)
 
     if kacl_version:
+        if no_link:
+            kacl_version.set_link(None)
         kacl_changelog_content = kacl.dump(kacl_version)
         click.echo(kacl_changelog_content)
     else:
